==> zzyj-financeintegration-api-3.0.0-20250912.021445-121-sources.jar: com/ejianc/business/financeintegration/PMSalary/vo/PMGzVO.java <==
package com.ejianc.business.financeintegration.PMSalary.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyDetailVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


@TableName("PMSALARY_GZ")
public class PMGzVO {
    public static final String GZ_PAY_RESULT_MESSAGE = "salarySystemResult";
    private static final long serialVersionUID = 1L;
    /**
     * 项目ID
     */
    private String id;

    /**
     * 账套名称
     */
    private String acName;

    /**
     * 账套编号
     */
    private String acCode;

    /**
     * 所属年月
     */
    private String yearMonth;

    /**
     * PM所对应单据
     */
    private String pmBillId;

    /**
     * 实发金额
     */
    private BigDecimal actualMny;



    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 状态（1-支付成功、0-支付失败）
     */
    private String state;

    /**
     * 引用标识（）创建时为 N 引用时为 Y
     */
    private String quoteFlag;
    private List<PMGzDetailVO> detailList = new ArrayList<>(); // 工资子实体


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getAcName() {
        return acName;
    }

    public void setAcName(String acName) {
        this.acName = acName;
    }

    public String getAcCode() {
        return acCode;
    }

    public void setAcCode(String acCode) {
        this.acCode = acCode;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }

    public String getPmBillId() {
        return pmBillId;
    }

    public void setPmBillId(String pmBillId) {
        this.pmBillId = pmBillId;
    }

    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getQuoteFlag() {
        return quoteFlag;
    }

    public void setQuoteFlag(String quoteFlag) {
        this.quoteFlag = quoteFlag;
    }

    public List<PMGzDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PMGzDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> zzyj-financeintegration-api-3.0.0-20251015.082513-127-sources.jar: com/ejianc/business/financeintegration/PMSalary/vo/PMGzVO.java <==
package com.ejianc.business.financeintegration.PMSalary.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyDetailVO;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


@TableName("PMSALARY_GZ")
public class PMGzVO implements Serializable {
    public static final String GZ_PAY_RESULT_MESSAGE = "salarySystemResult";
    private static final long serialVersionUID = 1L;
    /**
     * 项目ID
     */
    private String id;

    /**
     * 账套名称
     */
    private String acName;

    /**
     * 账套编号
     */
    private String acCode;

    /**
     * 所属年月
     */
    private String yearMonth;

    /**
     * PM所对应单据
     */
    private String pmBillId;

    /**
     * 实发金额
     */
    private BigDecimal actualMny;



    /**
     * 创建时间
     */
    private String createTime;

    /**
     * 修改时间
     */
    private String updateTime;

    /**
     * 状态（1-支付成功、0-支付失败）
     */
    private String state;

    /**
     * 引用标识（）创建时为 N 引用时为 Y
     */
    private String quoteFlag;
    private List<PMGzDetailVO> detailList = new ArrayList<>(); // 工资子实体


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getAcName() {
        return acName;
    }

    public void setAcName(String acName) {
        this.acName = acName;
    }

    public String getAcCode() {
        return acCode;
    }

    public void setAcCode(String acCode) {
        this.acCode = acCode;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }

    public String getPmBillId() {
        return pmBillId;
    }

    public void setPmBillId(String pmBillId) {
        this.pmBillId = pmBillId;
    }

    public BigDecimal getActualMny() {
        return actualMny;
    }

    public void setActualMny(BigDecimal actualMny) {
        this.actualMny = actualMny;
    }

    public String getCreateTime() {
        return createTime;
    }

    public void setCreateTime(String createTime) {
        this.createTime = createTime;
    }

    public String getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(String updateTime) {
        this.updateTime = updateTime;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getQuoteFlag() {
        return quoteFlag;
    }

    public void setQuoteFlag(String quoteFlag) {
        this.quoteFlag = quoteFlag;
    }

    public List<PMGzDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<PMGzDetailVO> detailList) {
        this.detailList = detailList;
    }
}
